Rev 514: Remove --allow-changes argument to svn-upgrade: it's always needed. in file:///data/jelmer/bzr-svn/0.4/

Jelmer Vernooij jelmer at samba.org
Thu Jul 12 09:28:37 BST 2007


At file:///data/jelmer/bzr-svn/0.4/

------------------------------------------------------------
revno: 514
revision-id: jelmer at samba.org-20070705093605-uxas60wc7x44nco5
parent: jelmer at samba.org-20070705021037-vo7x4mnvg7a4bv5q
committer: Jelmer Vernooij <jelmer at samba.org>
branch nick: main
timestamp: Thu 2007-07-05 11:36:05 +0200
message:
  Remove --allow-changes argument to svn-upgrade: it's always needed.
modified:
  __init__.py                    __init__.py-20051008155114-eae558e6cf149e1d
  upgrade.py                     upgrade.py-20070106192108-0rakplee2lzah4gs-1
=== modified file '__init__.py'
--- a/__init__.py	2007-07-04 23:11:59 +0000
+++ b/__init__.py	2007-07-05 09:36:05 +0000
@@ -163,10 +163,10 @@
     were mapped from svn revisions.
     """
     takes_args = ['svn_repository?']
-    takes_options = [Option('allow-changes', help='Allow content changes')]
+    takes_options = []
 
     @display_command
-    def run(self, svn_repository=None, allow_changes=False):
+    def run(self, svn_repository=None):
         from upgrade import upgrade_branch
         from bzrlib.errors import NoWorkingTree
         from bzrlib.workingtree import WorkingTree
@@ -190,7 +190,7 @@
         else:
             svn_repository = Repository.open(svn_repository)
 
-        upgrade_branch(branch_to, svn_repository, allow_changes)
+        upgrade_branch(branch_to, svn_repository, allow_changes=True)
 
         if wt_to is not None:
             wt_to.set_last_revision(branch_to.last_revision())

=== modified file 'upgrade.py'
--- a/upgrade.py	2007-07-05 02:10:37 +0000
+++ b/upgrade.py	2007-07-05 09:36:05 +0000
@@ -80,16 +80,16 @@
         return revid + suffix
 
 
-def upgrade_branch(branch, svn_repository, allow_change=False):
+def upgrade_branch(branch, svn_repository, allow_changes=False):
     """Upgrade a branch to the current mapping version.
     
     :param branch: Branch to upgrade.
     :param svn_repository: Repository to fetch new revisions from
     :param allow_change: Allow changes in mappings.
     """
     revid = branch.last_revision()
     renames = upgrade_repository(branch.repository, svn_repository, 
-              revid, allow_change)
+              revid, allow_changes)
     mutter('renames %r' % renames)
     if len(renames) > 0:
         branch.generate_revision_history(renames[revid])
@@ -80,16 +80,16 @@
     :param branch: Branch to upgrade.
     :param svn_repository: Repository to fetch new revisions from
-    :param allow_change: Allow changes in mappings.
+    :param allow_changes: Allow changes in mappings.
     """
     revid = branch.last_revision()




More information about the bazaar-commits mailing list